sequencetools.iterate_sequence_nwise_cyclic
===========================================

.. autofunction:: abjad.tools.sequencetools.iterate_sequence_nwise_cyclic.iterate_sequence_nwise_cyclic
   :noindex:
